@@ -14,6 +14,7 @@ namespace network {
 class AccessPoints;
 class WirelessConnection;
 class NetworkDeviceRealize;
+class AccessPointProxy;
 /**
  * @brief 无线网络设备-无线网卡
  */
@@ -21,7 +22,6 @@ class WirelessDevice : public NetworkDeviceBase
 {
     Q_OBJECT
 
-    friend class NetworkController;
     friend class NetworkInterProcesser;
     friend class NetworkManagerProcesser;
 
@@ -35,13 +35,18 @@ public:
     QList<WirelessConnection *> items() const;                      // 无线网络连接列表
     AccessPoints *activeAccessPoints() const;                       // 当前活动的无线连接
     bool hotspotEnabled() const;                                    // 是否开启热点
+    void disconnectNetwork();
 
 Q_SIGNALS:
-    void networkAdded(QList<AccessPoints *>);                       // wlan新增网络
-    void networkRemoved(QList<AccessPoints *>);                     // wlan列表减少网络
+    void networkAdded(const QList<AccessPoints *> &);               // wlan新增网络
+    void networkRemoved(const QList<AccessPoints *> &);             // wlan列表减少网络
+    void connectionFailed(const AccessPoints *);                    // 连接无线wlan失败，第一个参数为失败的热点，第二个参数为对应的connection的Uuid
     void connectionSuccess(const AccessPoints *);                   // 连接无线网络wlan成功，参数为对应的wlan
     void hotspotEnableChanged(const bool &);                        // 热点是否可用发生变化
     void accessPointInfoChanged(const QList<AccessPoints *> &);     // wlan信号强度发生变化的网络
+    void wirelessConnectionAdded(const QList<WirelessConnection *> &); // 新增连接
+    void wirelessConnectionRemoved(const QList<WirelessConnection *> &); // 删除连接
+    void wirelessConnectionPropertyChanged(const QList<WirelessConnection *> &); // 连接属性发生变化
 
 protected:
     WirelessDevice(NetworkDeviceRealize *networkInter, QObject *parent);
@@ -59,10 +64,6 @@ class AccessPoints : public QObject
 {
     Q_OBJECT
 
-    friend class WirelessDevice;
-    friend class WirelessDeviceInterRealize;
-    friend class DeviceManagerRealize;
-
     Q_PROPERTY(QString ssid READ ssid)
     Q_PROPERTY(int strength READ strength)
     Q_PROPERTY(bool secured READ secured)
@@ -75,8 +76,7 @@ class AccessPoints : public QObject
 public:
     enum class WlanType { wlan, wlan6 };
 
-protected:
-    AccessPoints(const QJsonObject &json, QObject *parent = Q_NULLPTR);
+    AccessPoints(AccessPointProxy *proxy, QObject *parent = nullptr);
     ~AccessPoints();
 
 public:
@@ -93,38 +93,34 @@ public:
     WlanType type() const;
 
 Q_SIGNALS:
-    void strengthChanged(const int) const;                          // 当前信号强度变化
+    void strengthChanged(const int);                                // 当前信号强度变化
     void connectionStatusChanged(ConnectionStatus);
     void securedChanged(bool);
 
-protected:
-    void updateAccessPoints(const QJsonObject &json);
-    void updateConnectionStatus(ConnectionStatus);
-
 private:
-    QJsonObject m_json;
-    QString m_devicePath;
-    ConnectionStatus m_status;
+    AccessPointProxy *m_proxy;
 };
 
 /**
  * @brief 无线连接信息
  */
 
-class WirelessConnection: public ControllItems
+class WirelessConnection : public ControllItems
 {
+    Q_OBJECT
+
     friend class WirelessDevice;
     friend class WirelessDeviceInterRealize;
     friend class DeviceManagerRealize;
+    friend class WirelessDeviceManagerRealize;
 
 public:
-    AccessPoints *accessPoints() const;                             // 返回当前对应的wlan的指针
-    ConnectionStatus status() const override;
+    WirelessConnection();
+    AccessPoints *accessPoints() const;  // 返回当前对应的wlan的指针
+    ~WirelessConnection() override;
+    bool connected();  // 网络是否连接成功
 
 protected:
-    WirelessConnection();
-    virtual ~WirelessConnection() override;
-
     static WirelessConnection *createConnection(AccessPoints *ap);
 
 private:
@@ -135,4 +131,4 @@ private:
 
 }
 
-#endif // UWIRELESSDEVICE_H
+#endif  // WIRELESSDEVICE_H
